@@ -143,7 +143,10 @@ def filter_order(order):
  
     try:
      filtered = {
+        "number": int(order["number"]),
         "store_url": CONFIG["url"],
+        "created_via": str(order["created_via"]),
+        "currency": str(order["currency"]),
         "order_id":int(order["id"]),
         "order_key":str(order["order_key"]),
         "total_tax": str(order["total_tax"]),
@@ -154,9 +157,25 @@ def filter_order(order):
         "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
         "discount_total":float(order["discount_total"]),
         "shipping_total":float(order["shipping_total"]),
+        "shipping_tax": float(order["shipping_tax"]),
+        "cart_tax": float(order["cart_tax"]),
+        "prices_include_tax": order["prices_include_tax"],
+        "customer_id": str(order["customer_id"]),
+        "customer_ip_address": str(order["customer_ip_address"]),
+        "customer_user_agent": str(order["customer_user_agent"]),
+        "customer_note": str(order["customer_note"]),
         "coupon_lines": order["coupon_lines"],
         "total":float(order["total"]),
-        "line_items":line_items
+        "payment_method": str(order["payment_method"]),
+        "payment_method_title": str(order["payment_method_title"]),
+        "transaction_id": str(order["transaction_id"]),
+        "date_paid": parser.parse(order["date_paid"]).replace(tzinfo=tzinfo).isoformat(),
+        "date_completed": parser.parse(order["date_completed"]).replace(tzinfo=tzinfo).isoformat(),
+        "set_paid": order["set_paid"],
+        "shipping_lines": order["shipping_lines"],
+        "line_items":line_items,
+        "fee_lines": order["fee_lines"],
+        "refunds": order["refunds"]
     }
     except:
         filtered = {}    
